# This file was auto-generated by Fern from our API Definition.

import typing

UpdatePlanRequestBodyPlanType = typing.Union[
    typing.Literal["product", "pricing_plan", "add_on", "overage", "billable_metric", "other"], typing.Any
]
