# This file was auto-generated by Fern from our API Definition.

import typing

CreateEnvironmentRequestBodyEnvironmentType = typing.Union[
    typing.Literal["development", "staging", "production"], typing.Any
]
