# This file was auto-generated by Fern from our API Definition.

import typing

UpdateEntityTraitDefinitionRequestBodyTraitType = typing.Union[
    typing.Literal["boolean", "currency", "date", "number", "string", "url"], typing.Any
]
