# This file was auto-generated by Fern from our API Definition.

import typing

UpdatePlanEntitlementRequestBodyValueType = typing.Union[
    typing.Literal["Boolean", "Numeric", "Trait", "Unlimited"], typing.Any
]
