# This file was auto-generated by Fern from our API Definition.

import typing

CreateOrUpdateConditionRequestBodyConditionType = typing.Union[
    typing.Literal["company", "metric", "trait", "user", "plan", "billing_product", "crm_product"], typing.Any
]
