# This file was auto-generated by Fern from our API Definition.

import typing

UpdateCompanyOverrideRequestBodyMetricPeriod = typing.Union[
    typing.Literal["current_month", "current_week", "current_day"], typing.Any
]
