# This file was auto-generated by Fern from our API Definition.

import typing

CreateOrUpdateRuleRequestBodyRuleType = typing.Union[
    typing.Literal["global_override", "company_override", "plan_entitlement", "standard", "default", "plan_audience"],
    typing.Any,
]
