# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ...core.datetime_utils import serialize_datetime
from ...core.pydantic_utilities import deep_union_pydantic_dicts, pydantic_v1


class ListMetricCountsParams(pydantic_v1.BaseModel):
    """
    Input parameters
    """

    company_id: typing.Optional[str] = None
    company_ids: typing.Optional[typing.List[str]] = None
    end_time: typing.Optional[dt.datetime] = None
    event_subtype: typing.Optional[str] = None
    event_subtypes: typing.Optional[typing.List[str]] = None
    grouping: typing.Optional[str] = None
    limit: typing.Optional[int] = None
    offset: typing.Optional[int] = None
    start_time: typing.Optional[dt.datetime] = None
    user_id: typing.Optional[str] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}
