# This file was auto-generated by Fern from our API Definition.

import typing

CreateOrUpdateConditionRequestBodyOperator = typing.Union[
    typing.Literal["eq", "ne", "gt", "gte", "lt", "lte"], typing.Any
]
